@@ -18,7 +18,7 @@
 library(R2MLwiN)
 ## Input the MLwiN tutorial data set
 # MLwiN folder
-if(!exists("mlwin")) mlwin ="C:/Program Files (x86)/MLwiN v2.26/"
+if(!exists("mlwin")) mlwin ="C:/Program Files (x86)/MLwiN v2.27/"
 while (!file.access(mlwin,mode=0)==0||!file.access(mlwin,mode=1)==0||!file.access(mlwin,mode=4)==0){
     cat("Please specify the MLwiN folder including the MLwiN executable:\n")
     mlwin=scan(what=character(0),sep ="\n")
@@ -52,14 +52,14 @@ formula="a_point ~ (0|cons)+(1|cons )"
 levID='pupil'
 estoptions= list(EstM=1)
 ## Fit the model
-mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin))
 
 ## Define the model
 formula="a_point ~ (0|cons+gcseav+gcse2+gcse3+gender)+(1|cons )"
 levID='pupil'
 estoptions= list(EstM=1, resi.store=T)
 ## Fit the model
-mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Normal', indata, estoptions,MLwiNPath=mlwin))
 
 resi=mymodel["residual"]
 FP=mymodel["FP"]
@@ -73,12 +73,12 @@ levID=c('pupil')
 ##IGLS
 estoptions= list(EstM=0)
 ## Fit the model
-mymodel=runMLwiN(formula, levID, D='Ordered Multinomial', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Ordered Multinomial', indata, estoptions,MLwiNPath=mlwin))
 
 ##MCMC
 estoptions= list(EstM=1)
 ## Fit the model
-mymodel=runMLwiN(formula, levID, D='Ordered Multinomial', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Ordered Multinomial', indata, estoptions,MLwiNPath=mlwin))
 
 # 13.4 Adding predictor variables . . . . . . . . . . . . . . . . . . . .191
 formula="logit(a_point,cons,A) ~ (0s|cons)+(0c|gcseav+gcse2+gcse3+gender)"
@@ -86,7 +86,7 @@ levID=c('pupil')
 ##MCMC
 estoptions= list(EstM=1)
 ## Fit the model
-mymodel=runMLwiN(formula, levID, D='Ordered Multinomial', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Ordered Multinomial', indata, estoptions,MLwiNPath=mlwin))
 
 # 13.5 Multilevel ordered response modelling . . . . . . . . . . . . . . 192
 formula="logit(a_point,cons,A) ~ (0s|cons)+(0c|gcseav+gcse2+gender) +( 2c | cons)"
@@ -94,7 +94,7 @@ levID=c('estab','pupil')
 ##MCMC
 estoptions= list(EstM=1)
 ## Fit the model
-mymodel=runMLwiN(formula, levID, D='Ordered Multinomial', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Ordered Multinomial', indata, estoptions,MLwiNPath=mlwin))
 
 
 formula="logit(a_point,cons,A) ~ (0s|cons)+(0c|gcseav+gcse2+gender) +( 2c | cons+gcseav )"
@@ -102,14 +102,14 @@ levID=c('estab','pupil')
 ##MCMC
 estoptions= list(EstM=1)
 ## Fit the model
-mymodel=runMLwiN(formula, levID, D='Ordered Multinomial', indata, estoptions,MLwiNPath=mlwin)
-sixway(mymodel["chains"][["RP2_var_cons_12345"]],acf.maxlag = 300,"sigma2v6")
+(mymodel=runMLwiN(formula, levID, D='Ordered Multinomial', indata, estoptions,MLwiNPath=mlwin))
+sixway(mymodel["chains"][,"RP2_var_cons_12345"],acf.maxlag = 300,"sigma2v6")
 
 ##Increases iterations to 50,000
 estoptions= list(EstM=1,mcmcMeth=list(iterations=50000))
 ## Fit the model
-mymodel=runMLwiN(formula, levID, D='Ordered Multinomial', indata, estoptions,MLwiNPath=mlwin)
-sixway(mymodel["chains"][["RP2_var_cons_12345"]],acf.maxlag = 300,"sigma2v6")
+(mymodel=runMLwiN(formula, levID, D='Ordered Multinomial', indata, estoptions,MLwiNPath=mlwin))
+sixway(mymodel["chains"][,"RP2_var_cons_12345"],acf.maxlag = 300,"sigma2v6")
 
 # Chapter learning outcomes . . . . . . . . . . . . . . . . . . . . . . .128
 
