@@ -18,7 +18,7 @@
 library(R2MLwiN)
 ## Input the MLwiN tutorial data set
 # MLwiN folder
-if(!exists("mlwin")) mlwin ="C:/Program Files (x86)/MLwiN v2.26/"
+if(!exists("mlwin")) mlwin ="C:/Program Files (x86)/MLwiN v2.27/"
 while (!file.access(mlwin,mode=0)==0||!file.access(mlwin,mode=1)==0||!file.access(mlwin,mode=4)==0){
     cat("Please specify the MLwiN folder including the MLwiN executable:\n")
     mlwin=scan(what=character(0),sep ="\n")
@@ -46,17 +46,17 @@ formula="c(written,csework)~(0|cons)+(1|cons)"
 levID='student'
 ##IGLS
 estoptions= list(EstM=0)
-mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin))
 ##MCMC
 estoptions= list(EstM=1)
-mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin))
 
 # 18.3 Adding predictor variables . . . . . . . . . . . . . . . . . . . .270
 
 formula="c(written,csework)~(0|cons+female)+(1|cons)"
 levID='student'
 estoptions= list(EstM=1)
-mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin))
 
 # 18.4 A multilevel multivariate model . . . . . . . . . . . . . . . . . 271
 
@@ -64,10 +64,10 @@ formula="c(written,csework)~(0|cons+female)+(2|cons)+(1|cons)"
 levID=c('school','student')
 ##Store residual chain at level 3: school
 estoptions= list(EstM=1,resi.store=T,resi.store.levs=3)
-mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin))
 
 lencateg = length(unique(indata[["school"]]))
-resi=na.omit(mymodel["resi.chains"][["resi_lev3"]])
+resi=na.omit(mymodel["resi.chains"][,"resi_lev3"])
 ##u0 and u1 alternates for each iteration (each column)
 resi=matrix(resi,nrow =lencateg*2)
 label=1:nrow(resi)
@@ -128,12 +128,12 @@ library(foreign); indata =read.dta("http://www.bristol.ac.uk/cmm/media/runmlwin/
 formula="c(written,csework)~(0|cons+female)+(1|cons)"
 levID='student'
 estoptions= list(EstM=1)
-mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin))
 
 formula="c(written,csework)~(0|cons+female)+(2|cons)+(1|cons)"
 levID=c('school','student')
 estoptions= list(EstM=1,mcmcMeth=list(dami=2))
-mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin))
 
 
 # 18.6 Imputation methods for missing data . . . . . . . . . . . . . . . 280
@@ -162,11 +162,11 @@ summary(indata)
 formula="c(es_core,biol_core,biol_r3,biol_r4,phys_core,phys_r2)~(0|cons+female)+(2|cons)+(1|cons)"
 levID=c('school','student')
 estoptions= list(EstM=0)
-mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin)
+(mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin))
 
 estoptions= list(EstM=1,mcmcMeth=list(dami=c(0,1000,2000,3000,4000,5000)))
-mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin)
-#mymodel["esample"]
+(mymodel=runMLwiN(formula, levID, D='Multivariate Normal', indata, estoptions,MLwiNPath=mlwin))
+head(mymodel["MIdata"])
 
 # Chapter learning outcomes . . . . . . . . . . . . . . . . . . . . . . .128
 
